@@ -130,9 +130,9 @@ def filterQuotesByBook(db, book, min_likes=0):
                 by_book.append(quote[0])
     return by_book
 
-def export(quotes, saveFile):
+def export(quotes, saveFile, enc=2):
 	from grtoolkit.Storage import File
-	save = File(saveFile, enc=0)
+	save = File(saveFile, enc=enc)
 
 	for i in range(0,len(quotes)):
 		if i == 1:
